@@ -2,7 +2,7 @@
 from pathlib import Path
 from flask import Flask
 
-from importlib.resources import files
+from importlib_resources import files
 
 # import app
 from app.views import depht, train, models, documentation
